@@ -71,7 +71,6 @@ bool RBlockReferenceData::hasBlockOwnership() const {
     return block->isOwnedByReference();
 }
 
-
 void RBlockReferenceData::setReferencedBlockName(const QString& blockName) {
     if (document == NULL) {
         qWarning("RBlockReferenceData::setReferencedBlockName(): "
@@ -417,14 +416,13 @@ QSharedPointer<REntity> RBlockReferenceData::queryEntity(REntity::Id entityId, b
     }
 
     if (document == NULL) {
-        qWarning("RBlockReferenceData::queryEntity: document is NULL");
+        qWarning() << "RBlockReferenceData::queryEntity: document is NULL";
         return QSharedPointer<REntity> ();
     }
 
     QSharedPointer<REntity> entity = document->queryEntity(entityId);
     if (entity.isNull()) {
-        qWarning("RBlockReferenceData::queryEntity: "
-            "entity %d is NULL", entityId);
+        qWarning() << "RBlockReferenceData::queryEntity: entity " << entityId << " is NULL";
         return QSharedPointer<REntity>();
     }
 
@@ -485,6 +483,9 @@ void RBlockReferenceData::applyColumnRowOffsetTo(REntity& entity, int col, int r
 }
 
 bool RBlockReferenceData::applyTransformationTo(REntity& entity) const {
+    if (document==NULL) {
+        return false;
+    }
     QSharedPointer<RBlock> block = document->queryBlockDirect(referencedBlockId);
     if (block.isNull()) {
         qWarning("RBlockReferenceData::applyTransformationTo: "
@@ -521,6 +522,10 @@ bool RBlockReferenceData::applyTransformationTo(REntity& entity) const {
 }
 
 bool RBlockReferenceData::applyTransformationTo(QSharedPointer<REntity>& entity) const {
+    if (document==NULL) {
+        return false;
+    }
+
     QSharedPointer<RBlock> block = document->queryBlockDirect(referencedBlockId);
     if (block.isNull()) {
         qWarning("RBlockReferenceData::applyTransformationTo: "
@@ -570,6 +575,10 @@ bool RBlockReferenceData::applyTransformationTo(QSharedPointer<REntity>& entity)
 }
 
 RTransform RBlockReferenceData::getTransform() const {
+    if (document==NULL) {
+        return RTransform();
+    }
+
     QSharedPointer<RBlock> block = document->queryBlockDirect(referencedBlockId);
     if (block.isNull()) {
         qWarning("RBlockReferenceData::getTransform: "
@@ -586,6 +595,9 @@ RTransform RBlockReferenceData::getTransform() const {
 }
 
 RVector RBlockReferenceData::mapToBlock(const RVector& v) const {
+    if (document==NULL) {
+        return RVector::invalid;
+    }
     QSharedPointer<RBlock> block = document->queryBlockDirect(referencedBlockId);
     if (block.isNull()) {
         qWarning("RBlockReferenceData::mapToBlock: "
@@ -616,6 +628,28 @@ bool RBlockReferenceData::isPixelUnit() const {
     return block->isPixelUnit();
 }
 
+bool RBlockReferenceData::isXRef() const {
+    if (document==NULL) {
+        return false;
+    }
+    QSharedPointer<RBlock> block = document->queryBlockDirect(referencedBlockId);
+    if (block==NULL) {
+        return false;
+    }
+    return block->isXRef();
+}
+
+bool RBlockReferenceData::loadXRef() const {
+    if (document==NULL) {
+        return false;
+    }
+    QSharedPointer<RBlock> block = document->queryBlockDirect(referencedBlockId);
+    if (block==NULL) {
+        return false;
+    }
+    return block->loadXRef();
+}
+
 QList<RRefPoint> RBlockReferenceData::getInternalReferencePoints(RS::ProjectionRenderingHint hint, QList<REntity::Id>* subEntityIds) const {
     QList<RRefPoint> ret;
 
