@@ -17,6 +17,7 @@
  * along with QCAD.
  */
 #include "RBlockReferenceEntity.h"
+#include "RBlock.h"
 #include "RDebug.h"
 #include "RDocument.h"
 #include "RExporter.h"
@@ -40,6 +41,7 @@ RPropertyTypeId RBlockReferenceEntity::PropertyDisplayedColor;
 RPropertyTypeId RBlockReferenceEntity::PropertyDrawOrder;
 
 RPropertyTypeId RBlockReferenceEntity::PropertyReferencedBlock;
+RPropertyTypeId RBlockReferenceEntity::PropertyXRef;
 RPropertyTypeId RBlockReferenceEntity::PropertyPositionX;
 RPropertyTypeId RBlockReferenceEntity::PropertyPositionY;
 RPropertyTypeId RBlockReferenceEntity::PropertyPositionZ;
@@ -96,6 +98,7 @@ void RBlockReferenceEntity::init() {
     RBlockReferenceEntity::PropertyDrawOrder.generateId(RBlockReferenceEntity::getRtti(), REntity::PropertyDrawOrder);
 
     RBlockReferenceEntity::PropertyReferencedBlock.generateId(RBlockReferenceEntity::getRtti(), "", QT_TRANSLATE_NOOP("REntity", "Referenced Block"));
+    RBlockReferenceEntity::PropertyXRef.generateId(RBlockReferenceEntity::getRtti(), "", QT_TRANSLATE_NOOP("REntity", "External Reference"));
     RBlockReferenceEntity::PropertyPositionX.generateId(RBlockReferenceEntity::getRtti(), QT_TRANSLATE_NOOP("REntity", "Position"), QT_TRANSLATE_NOOP("REntity", "X"), false, RPropertyAttributes::Geometry);
     RBlockReferenceEntity::PropertyPositionY.generateId(RBlockReferenceEntity::getRtti(), QT_TRANSLATE_NOOP("REntity", "Position"), QT_TRANSLATE_NOOP("REntity", "Y"), false, RPropertyAttributes::Geometry);
     RBlockReferenceEntity::PropertyPositionZ.generateId(RBlockReferenceEntity::getRtti(), QT_TRANSLATE_NOOP("REntity", "Position"), QT_TRANSLATE_NOOP("REntity", "Z"), false, RPropertyAttributes::Geometry);
@@ -109,7 +112,7 @@ void RBlockReferenceEntity::init() {
     RBlockReferenceEntity::PropertyRowSpacing.generateId(RBlockReferenceEntity::getRtti(), "", QT_TRANSLATE_NOOP("REntity", "Row Spacing"));
 
     // make sure title of property attributes group is translated:
-    QT_TRANSLATE_NOOP("REntity", "Attributes");
+    QString s = QT_TRANSLATE_NOOP("REntity", "Attributes");
 }
 
 QSet<RPropertyTypeId> RBlockReferenceEntity::getPropertyTypeIds(RPropertyAttributes::Option option) const {
@@ -291,6 +294,8 @@ QPair<QVariant, RPropertyAttributes> RBlockReferenceEntity::getProperty(
         return qMakePair(QVariant(data.columnSpacing), RPropertyAttributes());
     } else if (propertyTypeId == PropertyRowSpacing) {
         return qMakePair(QVariant(data.rowSpacing), RPropertyAttributes());
+    } else if (propertyTypeId == PropertyXRef) {
+        return qMakePair(QVariant(data.isXRef()), RPropertyAttributes(RPropertyAttributes::ReadOnly));
     } else if (propertyTypeId == PropertyReferencedBlock) {
         if (humanReadable) {
             RDocument* document = getData().getDocument();
@@ -392,6 +397,20 @@ void RBlockReferenceEntity::exportEntity(RExporter& e, bool preview, bool forceS
         return;
     }
 
+    QSharedPointer<RBlock> block = document->queryBlockDirect(data.referencedBlockId);
+    if (block.isNull()) {
+        recursionDepth--;
+        //qWarning() << "block" << data.referencedBlockId << "is NULL";
+        return;
+    }
+
+    QString xRefFileName = block->getXRefFileName();
+    bool isXRef = !xRefFileName.isEmpty();
+
+    if (isXRef) {
+        block->loadXRef();
+    }
+
     RObject::Id layer0Id = document->getLayer0Id();
     //bool layerIsOff = document->isLayerOff(getLayerId());
     //bool layer0IsOff = document->isLayerOff(layer0Id);
@@ -406,13 +425,6 @@ void RBlockReferenceEntity::exportEntity(RExporter& e, bool preview, bool forceS
 //    QSet<REntity::Id> attributeIds = document->queryChildEntities(getId(), RS::EntityAttribute);
 //    QList<REntity::Id> attributeList = document->getStorage().orderBackToFront(attributeIds);
 
-    QSharedPointer<RBlock> block = document->queryBlockDirect(data.referencedBlockId);
-    if (block.isNull()) {
-        recursionDepth--;
-        //qWarning() << "block" << data.referencedBlockId << "is NULL";
-        return;
-    }
-
     // transform for whole block reference:
     RTransform blockRefTransform;
     blockRefTransform = data.getTransform();
